from distutils.core import setup

setup(
    name="operacionescursopythonjjfr",
    packages=["ejercicio13"],
    version="0.1",
    license="MIT",
    description="Libreria de mates",
    author="JJFR",
    author_email="josejuanfloresraposo@gmail.com",
    keywords=[
        "operaciones",
        "suma",
        "resta",
        "multiplicaciones",
        "divisiones",
        "ejemplo",
    ],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Build Tools",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
    ],
)
